@@ -19,11 +19,11 @@
 import logging
 import math
 
-from PyQt6 import QtWidgets
+from PySide6 import QtWidgets as QtW
 
-import NanoVNASaver.AnalyticTools as At
-from NanoVNASaver.Analysis.Base import CUTOFF_VALS, MIN_CUTOFF_DAMPING, Analysis
-from NanoVNASaver.Formatting import format_frequency
+from .. import AnalyticTools as At
+from ..Formatting import format_frequency
+from .Base import CUTOFF_VALS, MIN_CUTOFF_DAMPING, Analysis
 
 logger = logging.getLogger(__name__)
 
@@ -42,37 +42,37 @@ class BandPassAnalysis(Analysis):
             "span_6.0dB",
             "q_factor",
         ):
-            self.label[label] = QtWidgets.QLabel()
+            self.label[label] = QtW.QLabel()
         for attn in CUTOFF_VALS:
-            self.label[f"{attn:.1f}dB_l"] = QtWidgets.QLabel()
-            self.label[f"{attn:.1f}dB_r"] = QtWidgets.QLabel()
+            self.label[f"{attn:.1f}dB_l"] = QtW.QLabel()
+            self.label[f"{attn:.1f}dB_r"] = QtW.QLabel()
 
         layout = self.layout
         layout.addRow(self.label["titel"])
         layout.addRow(
-            QtWidgets.QLabel(
+            QtW.QLabel(
                 f"Please place {self.app.markers[0].name}"
                 f" in the filter passband."
             )
         )
         layout.addRow("Result:", self.label["result"])
-        layout.addRow(QtWidgets.QLabel(""))
+        layout.addRow(QtW.QLabel(""))
 
         layout.addRow("Center frequency:", self.label["freq_center"])
         layout.addRow("Bandwidth (-3 dB):", self.label["span_3.0dB"])
         layout.addRow("Quality factor:", self.label["q_factor"])
         layout.addRow("Bandwidth (-6 dB):", self.label["span_6.0dB"])
-        layout.addRow(QtWidgets.QLabel(""))
+        layout.addRow(QtW.QLabel(""))
 
-        layout.addRow(QtWidgets.QLabel("Lower side:"))
+        layout.addRow(QtW.QLabel("Lower side:"))
         layout.addRow("Cutoff frequency:", self.label["3.0dB_l"])
         layout.addRow("-6 dB point:", self.label["6.0dB_l"])
         layout.addRow("-60 dB point:", self.label["60.0dB_l"])
         layout.addRow("Roll-off:", self.label["octave_l"])
         layout.addRow("Roll-off:", self.label["decade_l"])
-        layout.addRow(QtWidgets.QLabel(""))
+        layout.addRow(QtW.QLabel(""))
 
-        layout.addRow(QtWidgets.QLabel("Upper side:"))
+        layout.addRow(QtW.QLabel("Upper side:"))
         layout.addRow("Cutoff frequency:", self.label["3.0dB_r"])
         layout.addRow("-6 dB point:", self.label["6.0dB_r"])
         layout.addRow("-60 dB point:", self.label["60.0dB_r"])
