@@ -19,16 +19,16 @@
 import logging
 
 import numpy as np
-from PyQt6 import QtWidgets
+from PySide6 import QtWidgets
 
 # pylint: disable=import-error, no-name-in-module
 from scipy.signal import find_peaks, peak_prominences
 
-from NanoVNASaver.Analysis.Base import QHLine
-from NanoVNASaver.Analysis.SimplePeakSearchAnalysis import (
+from ..Formatting import format_frequency_short
+from .Base import QHLine
+from .SimplePeakSearchAnalysis import (
     SimplePeakSearchAnalysis,
 )
-from NanoVNASaver.Formatting import format_frequency_short
 
 logger = logging.getLogger(__name__)
 
