@@ -26,8 +26,8 @@ from dataclasses import dataclass
 
 from scipy.interpolate import interp1d
 
-from NanoVNASaver.RFTools import Datapoint
-from NanoVNASaver.Touchstone import Touchstone
+from .RFTools import Datapoint
+from .Touchstone import Touchstone
 
 IDEAL_SHORT = complex(-1, 0)
 IDEAL_OPEN = complex(1, 0)
@@ -243,6 +243,12 @@ class CalDataSet(UserDict):
     def frequencies(self) -> list[int]:
         return sorted(self.data.keys())
 
+    def freq_min(self) -> int:
+        return self.frequencies()[0] if self.frequencies() else 0
+
+    def freq_max(self) -> int:
+        return self.frequencies()[-1] if self.frequencies() else 0
+
     def get(self, key: int, default: CalData = None) -> CalData:
         return self.data.get(key, default)
 
