@@ -20,11 +20,10 @@ import logging
 import math
 
 import numpy as np
-from PyQt6 import QtGui
-
-from NanoVNASaver.Charts.Chart import Chart
-from NanoVNASaver.RFTools import Datapoint
+from PySide6 import QtGui
 
+from ..RFTools import Datapoint
+from .Chart import Chart
 from .Frequency import FrequencyChart
 
 logger = logging.getLogger(__name__)
