@@ -20,12 +20,12 @@ import logging
 import math
 from dataclasses import dataclass
 
-from PyQt6 import QtGui
+from PySide6 import QtGui
 
-from NanoVNASaver.Charts.Chart import Chart
-from NanoVNASaver.Charts.Frequency import FrequencyChart
-from NanoVNASaver.RFTools import Datapoint
-from NanoVNASaver.SITools import log_floor_125
+from ..RFTools import Datapoint
+from ..SITools import log_floor_125
+from .Chart import Chart
+from .Frequency import FrequencyChart
 
 logger = logging.getLogger(__name__)
 
