@@ -20,8 +20,8 @@ import logging
 import math
 
 import numpy as np
-from PyQt6.QtCore import QPoint, QRect, Qt
-from PyQt6.QtGui import (
+from PySide6.QtCore import QPoint, QRect, Qt
+from PySide6.QtGui import (
     QAction,
     QActionGroup,
     QMouseEvent,
@@ -31,9 +31,9 @@ from PyQt6.QtGui import (
     QPen,
     QResizeEvent,
 )
-from PyQt6.QtWidgets import QInputDialog, QMenu, QSizePolicy
+from PySide6.QtWidgets import QInputDialog, QMenu, QSizePolicy
 
-from NanoVNASaver.Charts.Chart import Chart
+from .Chart import Chart
 
 logger = logging.getLogger(__name__)
 
@@ -61,7 +61,7 @@ class TDRChart(Chart):
     fixed_values: bool = False
     marker_location: int = -1
 
-    def __init__(self, name) -> None:  # noqa: PLR0915
+    def __init__(self, name) -> None:
         super().__init__(name)
         self.tdrWindow = None
 
@@ -354,9 +354,9 @@ class TDRChart(Chart):
         qp.drawText(
             self.leftMargin - 10,
             self.topMargin + height + 15,
-            f"""{str(round(
-                self.tdrWindow.distance_axis[min_index] / 2, self.decimals))
-                }m""",
+            f"""{round(
+                self.tdrWindow.distance_axis[min_index] / 2, self.decimals)
+                !s}m""",
         )
 
     def _draw_y_ticks(
