@@ -18,15 +18,17 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 import logging
 
-from PyQt6 import QtCore, QtWidgets
+from PySide6 import QtCore, QtWidgets
+
+from NanoVNASaver import NanoVNASaver
 
 logger = logging.getLogger(__name__)
 
 
 class Control(QtWidgets.QGroupBox):
-    updated = QtCore.pyqtSignal(object)
+    updated = QtCore.Signal(object)
 
-    def __init__(self, app: QtWidgets.QWidget, title: str = ""):
+    def __init__(self, app: NanoVNASaver, title: str = ""):
         super().__init__()
         self.app = app
         self.setMaximumWidth(250)
