@@ -19,7 +19,7 @@
 import math
 from numbers import Number
 
-from NanoVNASaver import SITools
+from . import SITools
 
 FMT_FREQ = SITools.Format()
 FMT_FREQ_SHORT = SITools.Format(max_nr_digits=4)
@@ -85,7 +85,7 @@ def format_gain(val: float, invert: bool = False) -> str:
 
 
 def format_q_factor(val: float, allow_negative: bool = False) -> str:
-    if (not allow_negative and val < 0) or abs(val > 10000.0):  # noqa: PLR2004
+    if (not allow_negative and val < 0) or abs(val > 10000.0):
         return "\N{INFINITY}"
     return str(SITools.Value(val, fmt=FMT_Q_FACTOR))
 
