@@ -25,19 +25,21 @@ import serial
 from serial.tools import list_ports
 from serial.tools.list_ports_common import ListPortInfo
 
-from NanoVNASaver.Hardware.AVNA import AVNA
-from NanoVNASaver.Hardware.JNCRadio_VNA_3G import JNCRadio_VNA_3G
-from NanoVNASaver.Hardware.NanoVNA import NanoVNA
-from NanoVNASaver.Hardware.NanoVNA_F import NanoVNA_F
-from NanoVNASaver.Hardware.NanoVNA_F_V2 import NanoVNA_F_V2
-from NanoVNASaver.Hardware.NanoVNA_H import NanoVNA_H
-from NanoVNASaver.Hardware.NanoVNA_H4 import NanoVNA_H4
-from NanoVNASaver.Hardware.NanoVNA_V2 import NanoVNA_V2
-from NanoVNASaver.Hardware.Serial import Interface, drain_serial
-from NanoVNASaver.Hardware.SV4401A import SV4401A
-from NanoVNASaver.Hardware.SV6301A import SV6301A
-from NanoVNASaver.Hardware.TinySA import TinySA, TinySA_Ultra
-from NanoVNASaver.Hardware.VNA import VNA
+from .AVNA import AVNA
+from .JNCRadio_VNA_3G import JNCRadio_VNA_3G
+from .LiteVNA64 import LiteVNA64
+from .NanoVNA import NanoVNA
+from .NanoVNA_F import NanoVNA_F
+from .NanoVNA_F_V2 import NanoVNA_F_V2
+from .NanoVNA_F_V3 import NanoVNA_F_V3
+from .NanoVNA_H import NanoVNA_H
+from .NanoVNA_H4 import NanoVNA_H4
+from .NanoVNA_V2 import NanoVNA_V2
+from .Serial import Interface, drain_serial
+from .SV4401A import SV4401A
+from .SV6301A import SV6301A
+from .TinySA import TinySA, TinySA_Ultra
+from .VNA import VNA
 
 logger = logging.getLogger(__name__)
 
@@ -58,6 +60,7 @@ NAME2DEVICE = {
     "H4": NanoVNA_H4,
     "H": NanoVNA_H,
     "F_V2": NanoVNA_F_V2,
+    "F_V3": NanoVNA_F_V3,
     "F": NanoVNA_F,
     "NanoVNA": NanoVNA,
     "tinySA": TinySA,
@@ -65,6 +68,7 @@ NAME2DEVICE = {
     "JNCRadio": JNCRadio_VNA_3G,
     "SV4401A": SV4401A,
     "SV6301A": SV6301A,
+    "LiteVNA64": LiteVNA64,
     "Unknown": NanoVNA,
 }
 
@@ -145,9 +149,10 @@ def get_comment(iface: Interface) -> str:
     logger.info("Finding correct VNA type...")
     with iface.lock:
         vna_version = detect_version(iface)
-
     if vna_version == "v2":
         return "S-A-A-2"
+    elif vna_version == "lite_vna_64":
+        return "LiteVNA64"
 
     logger.info("Finding firmware variant...")
     info = get_info(iface)
@@ -156,6 +161,7 @@ def get_comment(iface: Interface) -> str:
         ("NanoVNA-H 4", "H4"),
         ("NanoVNA-H", "H"),
         ("NanoVNA-F_V2", "F_V2"),
+        ("NanoVNA-F_V3", "F_V3"),
         ("NanoVNA-F", "F"),
         ("NanoVNA", "NanoVNA"),
         ("tinySA4", "tinySA_Ultra"),
@@ -189,7 +195,9 @@ def detect_version(serial_port: serial.Serial) -> str:
         if data.startswith("\r\n?\r\nch> "):
             return "vh"
         if data.startswith("2"):
-            return "v2"
+            return (
+                "lite_vna_64" if LiteVNA64.is_lite_vna_64(serial_port) else "v2"
+            )
         logger.debug("Retry detection: %s", i + 1)
     logger.error("No VNA detected. Hardware responded to CR with: %s", data)
     return ""
