@@ -21,11 +21,11 @@ import struct
 
 import numpy as np
 import serial
-from PyQt6.QtGui import QImage, QPixmap
+from PySide6.QtGui import QImage, QPixmap
 
-from NanoVNASaver.Hardware.Serial import Interface, drain_serial
-from NanoVNASaver.Hardware.VNA import VNA
-from NanoVNASaver.Version import Version
+from ..utils import Version
+from .Serial import Interface, drain_serial
+from .VNA import VNA
 
 logger = logging.getLogger(__name__)
 
@@ -38,10 +38,10 @@ class NanoVNA(VNA):
     def __init__(self, iface: Interface):
         super().__init__(iface)
         self.sweep_method = "sweep"
-        self.read_features()
+        self.init_features()
         logger.debug("Setting initial start,stop")
         self.start, self.stop = self._get_running_frequencies()
-        self.sweep_max_freq_Hz = 300e6
+        self.sweep_max_freq_hz = 300e6
         self._sweepdata = []
 
     def _get_running_frequencies(self):
@@ -111,13 +111,13 @@ class NanoVNA(VNA):
         elif self.sweep_method == "scan":
             list(self.exec_command(f"scan {start} {stop} {self.datapoints}"))
 
-    def read_features(self):
-        super().read_features()
-        if self.version >= Version("0.7.1"):
+    def init_features(self) -> None:
+        super().init_features()
+        if self.version >= Version.parse("0.7.1"):
             logger.debug("Using scan mask command.")
             self.features.add("Scan mask command")
             self.sweep_method = "scan_mask"
-        elif self.version >= Version("0.2.0"):
+        elif self.version >= Version.parse("0.2.0"):
             logger.debug("Using new scan command.")
             self.features.add("Scan command")
             self.sweep_method = "scan"
