@@ -19,18 +19,16 @@
 import logging
 from enum import Enum
 from time import sleep
-from typing import TYPE_CHECKING
 
 import numpy as np
-from PyQt6.QtCore import QObject, QRunnable, pyqtSignal, pyqtSlot
+from PySide6.QtCore import QObject, QThread, Signal, Slot
 
-from NanoVNASaver.Calibration import correct_delay
-from NanoVNASaver.RFTools import Datapoint
-from NanoVNASaver.Settings.Sweep import Sweep, SweepMode
+from NanoVNASaver import NanoVNASaver
 
-if TYPE_CHECKING:
-    from NanoVNASaver.Hardware.VNA import VNA
-    from NanoVNASaver.NanoVNASaver import NanoVNASaver as NanoVNA
+from .Calibration import correct_delay
+from .Hardware.VNA import VNA
+from .RFTools import Datapoint
+from .Settings.Sweep import Sweep, SweepMode
 
 logger = logging.getLogger(__name__)
 
@@ -56,35 +54,43 @@ def truncate(values: list[list[complex]], count: int) -> list[list[complex]]:
 
 
 class WorkerSignals(QObject):
-    updated = pyqtSignal()
-    finished = pyqtSignal()
-    sweep_error = pyqtSignal()
+    updated = Signal()
+    finished = Signal()
+    sweep_error = Signal()
 
 
+# TODO do we need it for QThread?
 class SweepState(Enum):
     STOPPED = 0
     RUNNING = 1
 
 
-class SweepWorker(QRunnable):
-    def __init__(self, app: "NanoVNA") -> None:
+class SweepWorker(QThread):
+
+
+    def __init__(self, app: NanoVNASaver) -> None:
         super().__init__()
         logger.info("Initializing SweepWorker")
         self.signals: WorkerSignals = WorkerSignals()
-        self.app: NanoVNA = app
+        self.app = app
         self.sweep = Sweep()
-        self.setAutoDelete(False)
+        #self.setAutoDelete(False)
         self.percentage: float = 0.0
         self.data11: list[Datapoint] = []
         self.data21: list[Datapoint] = []
         self.rawData11: list[Datapoint] = []
         self.rawData21: list[Datapoint] = []
         self.init_data()
-        self.state: "SweepState" = SweepState.STOPPED
+        self.state = SweepState.STOPPED
         self.error_message: str = ""
         self.offsetDelay: float = 0.0
 
-    @pyqtSlot()
+    @Slot()
+    def quit(self) -> None:
+       self.state = SweepState.STOPPED
+       super().quit()
+
+    @Slot()
     def run(self) -> None:
         try:
             self._run()
