@@ -23,112 +23,44 @@ import re
 from time import localtime, strftime
 from urllib import error, request
 
-from PyQt6 import QtCore, QtGui, QtWidgets
+from PySide6 import QtCore, QtWidgets
 
-from NanoVNASaver.About import INFO_URL, LATEST_URL, TAGS_KEY, TAGS_URL
-from NanoVNASaver.Version import Version
-from NanoVNASaver.Windows.Defaults import make_scrollable
+from NanoVNASaver import NanoVNASaver
+
+from ..About import LATEST_URL, TAGS_KEY, TAGS_URL
+from ..utils import Version, get_app_version, get_runtime_information
+from .ui.about import Ui_DialogAbout
 
 logger = logging.getLogger(__name__)
 
 
-class AboutWindow(QtWidgets.QWidget):
-    def __init__(self, app: QtWidgets.QWidget):
-        super().__init__()
+class AboutWindow(QtWidgets.QDialog):
+    def __init__(self, app: NanoVNASaver):
+        super(AboutWindow, self).__init__()
+        self.ui = Ui_DialogAbout()
+        self.ui.setupUi(self)
+
         self.app = app
 
-        self.setWindowTitle("About NanoVNASaver")
-        self.setWindowIcon(self.app.icon)
+        self.ui.l_app_version.setText(get_app_version())
 
-        top_layout = QtWidgets.QVBoxLayout()
-        make_scrollable(self, top_layout)
+        self.ui.txt_runtime_info.setText("\n".join(get_runtime_information()))
+        self.ui.btn_copy_runtime_info.clicked.connect(self.copy_runtime_info)
 
-        upper_layout = QtWidgets.QHBoxLayout()
-        top_layout.addLayout(upper_layout)
-        QtGui.QShortcut(QtCore.Qt.Key.Key_Escape, self, self.hide)
-
-        icon_layout = QtWidgets.QVBoxLayout()
-        upper_layout.addLayout(icon_layout)
-        icon = QtWidgets.QLabel()
-        icon.setPixmap(self.app.icon.pixmap(128, 128))
-        icon_layout.addWidget(icon)
-        icon_layout.addStretch()
-
-        info_layout = QtWidgets.QVBoxLayout()
-        upper_layout.addLayout(info_layout)
-        upper_layout.addStretch()
-
-        info_layout.addWidget(
-            QtWidgets.QLabel(f"NanoVNASaver version {self.app.version}")
-        )
-        info_layout.addWidget(QtWidgets.QLabel(""))
-        info_layout.addWidget(
-            QtWidgets.QLabel(
-                "\N{COPYRIGHT SIGN} Copyright 2019, 2020 Rune B. Broberg\n"
-                "\N{COPYRIGHT SIGN} Copyright 2020ff NanoVNA-Saver Authors"
-            )
-        )
-        info_layout.addWidget(
-            QtWidgets.QLabel("This program comes with ABSOLUTELY NO WARRANTY")
-        )
-        info_layout.addWidget(
-            QtWidgets.QLabel(
-                "This program is licensed under the"
-                " GNU General Public License version 3"
-            )
-        )
-        info_layout.addWidget(QtWidgets.QLabel(""))
-        link_label = QtWidgets.QLabel(
-            f'For further details, see: <a href="{INFO_URL}">' f"{INFO_URL}"
-        )
-        link_label.setOpenExternalLinks(True)
-        info_layout.addWidget(link_label)
-        info_layout.addWidget(QtWidgets.QLabel(""))
-
-        lower_layout = QtWidgets.QVBoxLayout()
-        top_layout.addLayout(lower_layout)
-
-        btn_check_version = QtWidgets.QPushButton(
-            "Check for NanoVNASaver updates"
-        )
-        btn_check_version.clicked.connect(self.findUpdates)
-
-        self.updateLabel = QtWidgets.QLabel()
-
-        update_hbox = QtWidgets.QHBoxLayout()
-        update_hbox.addWidget(btn_check_version)
-        update_hbox.addStretch()
-        lower_layout.addLayout(update_hbox)
-        lower_layout.addWidget(self.updateLabel)
-
-        lower_layout.addStretch()
-
-        self.versionLabel = QtWidgets.QLabel(
-            "NanoVNA Firmware Version: Not connected."
-        )
-        lower_layout.addWidget(self.versionLabel)
-
-        lower_layout.addStretch()
-
-        btn_ok = QtWidgets.QPushButton("Ok")
-        btn_ok.clicked.connect(lambda: self.close())
-        lower_layout.addWidget(btn_ok)
+        self.ui.btn_updates.clicked.connect(self.find_updates)
 
     def show(self):
         super().show()
-        self.updateLabels()
+        self.update_labels()
 
-    def updateLabels(self):
+    def update_labels(self):
         with contextlib.suppress(IOError, AttributeError):
-            if self.app.vna.connected():
-                self.versionLabel.setText(
-                    f"NanoVNA Firmware Version: {self.app.vna.name} "
-                    f"v{self.app.vna.version}"
-                )
-            else:
-                self.versionLabel.setText(
-                    "NanoVNA Firmware Version: Not connected."
-                )
+            device_version = (
+                f"{self.app.vna.name} v{self.app.vna.version}"
+                if self.app.vna.connected()
+                else "not connected"
+            )
+            self.ui.l_dev_version.setText(device_version)
 
     # attempt to scan the TAGS_URL web page for something that looks like
     # a version tag. assume the first match with a line containing the TAGS_KEY
@@ -139,7 +71,9 @@ class AboutWindow(QtWidgets.QWidget):
     # check-for-updates and display a pop-up if any are found when this
     # function is called with automatic=True.
 
-    def findUpdates(self, automatic=False):
+    @QtCore.Slot()
+    def find_updates(self, automatic=False):
+        version_label = self.ui.l_updates_status
         try:
             req = request.Request(TAGS_URL)
             req.add_header("User-Agent", f"NanoVNASaver/{self.app.version}")
@@ -147,7 +81,7 @@ class AboutWindow(QtWidgets.QWidget):
                 line = ln.decode("utf-8")
                 found_latest_version = TAGS_KEY in line
                 if found_latest_version:
-                    latest_version = Version(
+                    latest_version = Version.parse(
                         re.search(r"(\d+\.\d+\.\d+)", line).group()
                     )
                     break
@@ -155,24 +89,24 @@ class AboutWindow(QtWidgets.QWidget):
             logger.exception(
                 "Checking for updates produced an HTTP exception: %s", e
             )
-            self.updateLabel.setText(f"{e}\n{TAGS_URL}")
+            version_label.setText(f"{e}\n{TAGS_URL}")
             return
         except TypeError as e:
             logger.exception(
                 "Checking for updates provided an unparseable file: %s", e
             )
-            self.updateLabel.setText("Data error reading versions.")
+            version_label.setText("Data error reading versions.")
             return
         except error.URLError as e:
             logger.exception(
                 "Checking for updates produced a URL exception: %s", e
             )
-            self.updateLabel.setText("Connection error.")
+            version_label.setText("Connection error.")
             return
 
         if found_latest_version:
             logger.info("Latest version is %s", latest_version)
-            this_version = Version(self.app.version)
+            this_version = Version.parse(self.app.version)
             logger.info("This is %s", this_version)
             if latest_version > this_version:
                 logger.info("New update available: %s!", latest_version)
@@ -191,16 +125,16 @@ class AboutWindow(QtWidgets.QWidget):
                         "There is a new update for NanoVNASaver available!\n"
                         f"Version {latest_version}\n\n",
                     )
-                self.updateLabel.setText(
+                version_label.setText(
                     f'<a href="{LATEST_URL}">View release page for version '
                     f"{latest_version} in browser</a>"
                 )
-                self.updateLabel.setOpenExternalLinks(True)
+                version_label.setOpenExternalLinks(True)
             else:
                 # Probably don't show a message box, just update the screen?
                 # Maybe consider showing it if not an automatic update.
                 #
-                self.updateLabel.setText(
+                version_label.setText(
                     f"NanoVNASaver is up to date as of: "
                     f"{strftime('%Y-%m-%d %H:%M:%S', localtime())}"
                 )
@@ -208,8 +142,13 @@ class AboutWindow(QtWidgets.QWidget):
             # not good. was gw able to find TAGS_KEY in file in TAGS_URL
             # content! if we get here, something may have changed in the way
             # github creates the .../latest web page.
-            self.updateLabel.setText(
+            version_label.setText(
                 "ERROR - Unable to determine what the latest version is!"
             )
-            logger.error(f"Can't find {TAGS_KEY} in {TAGS_URL} content.")
+            logger.error("Can't find %s in %s content.", TAGS_KEY, TAGS_URL)
         return
+
+    @QtCore.Slot()
+    def copy_runtime_info(self) -> None:
+        self.ui.txt_runtime_info.selectAll()
+        self.ui.txt_runtime_info.copy()
