@@ -18,7 +18,9 @@
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 import logging
 
-from PyQt6 import QtCore, QtGui, QtWidgets
+from PySide6 import QtCore, QtGui, QtWidgets
+
+# from .ui import get_window_icon
 
 logger = logging.getLogger(__name__)
 
@@ -29,7 +31,7 @@ class ScreenshotWindow(QtWidgets.QLabel):
     def __init__(self):
         super().__init__()
         self.setWindowTitle("Screenshot")
-        # TODO : self.setWindowIcon(self.app.icon)
+        # TODO : self.setWindowIcon(get_window_icon())
 
         QtGui.QShortcut(QtCore.Qt.Key.Key_Escape, self, self.hide)
         self.setContextMenuPolicy(
